=== modified file 'NEWS'
--- NEWS	2009-01-15 22:51:27 +0000
+++ NEWS	2009-01-18 01:48:15 +0000
@@ -29,6 +29,9 @@
     * ``bzr init`` will now print a little less verbose output.
       (Marius Kruger)
 
+    * Rule-based preferences can now accept multiple patterns for a set of
+      rules.  (Marius Kruger)
+
   BUG FIXES:
 
     * ``bzr log FILE`` now correctly shows mainline revisions merging

=== modified file 'bzrlib/help_topics/en/rules.txt'
--- bzrlib/help_topics/en/rules.txt	2008-08-14 17:25:43 +0000
+++ bzrlib/help_topics/en/rules.txt	2009-01-20 02:12:35 +0000
@@ -6,12 +6,12 @@
 
 Rules are defined in ini file format where the sections are file glob
 patterns and the contents of each section are the preferences for files
-matching that pattern. For example::
+matching that pattern(s). For example::
 
     [name *.bat]
     eol = dos
 
-    [name *.html]
+    [name *.html *.xml]
     keywords = escape
 
 Preferences like these are useful for commands and plugins wishing to
@@ -32,5 +32,5 @@
 the top of the file. Rule patterns use exactly the same conventions
 as ignore patterns. See ``bzr help patterns`` for details.
 
-Note: Patterns containing square brackets should be surrounded in
-quotes to ensure they are corrected parsed.
+Note: Patterns containing square brackets or spaces should be
+surrounded in quotes to ensure they are corrected parsed.

=== modified file 'bzrlib/rules.py'
--- bzrlib/rules.py	2008-07-18 08:40:57 +0000
+++ bzrlib/rules.py	2009-01-20 02:12:35 +0000
@@ -21,6 +21,7 @@
 
 from bzrlib import (
     config,
+    commands,
     errors,
     globbing,
     osutils,
@@ -73,8 +74,15 @@
         options = {'encoding': 'utf-8'}
         self._cfg = configobj.ConfigObj(inifile, options=options)
         sections = self._cfg.keys()
-        patterns = [s[FILE_PREFS_PREFIX_LEN:] for s in sections
-            if s.startswith(FILE_PREFS_PREFIX)]
+        patterns = []
+        self.pattern_to_section = {}
+        for s in sections:
+            if s.startswith(FILE_PREFS_PREFIX):
+                file_patterns = commands.shlex_split_unicode(
+                    s[FILE_PREFS_PREFIX_LEN:])
+                patterns.extend(file_patterns)
+                for fp in file_patterns:
+                    self.pattern_to_section[fp] = s
         if len(patterns) < len(sections):
             unknowns = [s for s in sections
                 if not s.startswith(FILE_PREFS_PREFIX)]
@@ -92,7 +100,7 @@
         if pat is None:
             return ()
         else:
-            all = self._cfg[FILE_PREFS_PREFIX + pat]
+            all = self._cfg[self.pattern_to_section[pat]]
             return tuple(all.items())
 
     def get_selected_items(self, path, names):
@@ -103,7 +111,7 @@
         if pat is None:
             return ()
         else:
-            all = self._cfg[FILE_PREFS_PREFIX + pat]
+            all = self._cfg[self.pattern_to_section[pat]]
             return tuple((k, all.get(k)) for k in names)
 
 

=== modified file 'bzrlib/tests/test_rules.py'
--- bzrlib/tests/test_rules.py	2008-07-18 08:40:57 +0000
+++ bzrlib/tests/test_rules.py	2009-01-18 01:07:21 +0000
@@ -62,6 +62,19 @@
         self.assertEquals((('foo', 'bar'),),
             rs.get_selected_items('a.txt', ['foo']))
 
+    def test_get_items_from_multiple_glob_match(self):
+        rs = self.make_searcher(
+            "[name *.txt *.py 'x x' \"y y\"]\nfoo=bar\na=True\n")
+        self.assertEquals((), rs.get_items('NEWS'))
+        self.assertEquals((('foo', 'bar'), ('a', 'True')),
+            rs.get_items('a.py'))
+        self.assertEquals((('foo', 'bar'), ('a', 'True')),
+            rs.get_items('a.txt'))
+        self.assertEquals((('foo', 'bar'), ('a', 'True')),
+            rs.get_items('x x'))
+        self.assertEquals((('foo', 'bar'), ('a', 'True')),
+            rs.get_items('y y'))
+
     def test_get_items_pathname_match(self):
         rs = self.make_searcher("[name ./a.txt]\nfoo=baz\n")
         self.assertEquals((('foo', 'baz'),),

